@@ -1,5 +1,8 @@
 package LWP::Authen::OAuth2::ServiceProvider::Google;
 
+# ABSTRACT: Google OAuth2
+our $VERSION = '0.18'; # VERSION
+
 use strict;
 use warnings;
 
@@ -123,18 +126,22 @@ sub request_required_params {
     return ("redirect_uri", $self->SUPER::request_required_params());
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-LWP::Authen::OAuth2::ServiceProvider::Google - Access Google OAuth2 APIs
+LWP::Authen::OAuth2::ServiceProvider::Google - Google OAuth2
 
 =head1 VERSION
 
-Version 0.02
-
-=cut
-
-package LWP::Authen::OAuth2::ServiceProvider::Google;
-our $VERSION = '0.02';
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -254,7 +261,7 @@ Google's documentation.
 
 It can be specified in the constructor with:
 
-    client_type => "web server",
+    client_type => "installed",
 
 On the first time it is the client's responsibility to open a browser and
 send the user to C<$oauth2->authorization_url(...)>.  If you pass in
@@ -292,98 +299,25 @@ support.
 
 =back
 
-=head1 AUTHOR
-
-Ben Tilly, C<< <btilly at gmail.com> >>
-
-=head1 BUGS
-
-The main bug is that out of 6 client types, 5 of which could reasonably be
-supported, only two are so far.
-
-Please report any bugs or feature requests to
-C<bug-lwp-authen-oauth2 at rt.cpan.org>, or through
-the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=LWP-Authen-OAuth2>.  I will
-be notified, and then you'll automatically be notified of progress on your
-bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc LWP::Authen::OAuth2::ServiceProvider
-
-You can also look for information at:
+=head1 AUTHORS
 
 =over 4
 
-=item Github (submit patches here)
+=item *
 
-L<https://github.com/btilly/perl-oauth2>
+Ben Tilly, <btilly at gmail.com>
 
-=item RT: CPAN's request tracker (report bugs here)
+=item *
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=LWP-Authen-OAuth2>
-
-=item AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/LWP-Authen-OAuth2>
-
-=item CPAN Ratings
-
-L<http://cpanratings.perl.org/d/LWP-Authen-OAuth2>
+Thomas Klausner <domm@plix.at>
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
+=head1 COPYRIGHT AND LICENSE
 
-Thanks to L<Rent.com|http://www.rent.com> for their generous support in
-letting me develop and release this module.  My thanks also to Nick
-Wellnhofer <wellnhofer@aevum.de> for Net::Google::Analytics::OAuth2 which
-was very enlightening while I was trying to figure out the details of how to
-connect to Google with OAuth2.
+This software is copyright (c) 2013 - 2021 by Ben Tilly, Rent.com, Thomas Klausner.
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2013 Rent.com.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
